@@ -6,9 +6,10 @@ from .LoginStepHandler import LoginStepHandler
 class GetPsessionidHandler(LoginStepHandler):
     def next_step(self, accumulated, last_response: Response) -> ({}, Response):
         self.session.headers.update({"Referer": "http://d1.web2.qq.com/proxy.html?v=20151105001&callback=1&id=2"})
+        self.session.headers.update({"Origin": "http://d1.web2.qq.com"})
         data_r = {
             "ptwebqq": accumulated["ptwebqq"],
-            "clientid": 53999199,
+            "clientid": accumulated["clientid"],
             "psessionid": "",
             "status": "online"
         }
@@ -17,4 +18,5 @@ class GetPsessionidHandler(LoginStepHandler):
         response_data = response.json()
         accumulated["uin"] = response_data["result"]["uin"]
         accumulated["psessionid"] = response_data["result"]["psessionid"]
+        print("psession done")
         return accumulated, response
