@@ -4,9 +4,10 @@ from .LoginStepHandler import LoginStepHandler
 
 
 class LoginPipeline:
-    def __init__(self, session: requests.Session) -> None:
+    def __init__(self, session: requests.Session, exception_handler) -> None:
         self.pipeline = []
         self.session = session
+        self.exception_handler = exception_handler
 
     def add_step(self, next_step: LoginStepHandler) -> None:
         self.pipeline.append(next_step)
@@ -19,12 +20,10 @@ class LoginPipeline:
             try:
                 for step in self.pipeline:
                     accumulated, response = step.next_step(accumulated, response)
-            except BarcodeExpiredException:
-                self.session.cookies.clear()
-                self.session.headers.clear()
-                print("Barcode expired, please try again.")
-                restart = True
             except Exception as ex:
-                print(ex)
+                # self.session.cookies.clear()
+                # self.session.headers.clear()
+                # print("Barcode expired, please try again.")
+                restart = self.exception_handler(ex) if self.exception_handler is not None else True
 
         return accumulated, response
